from uuid import UUID

from sqlalchemy import insert, select
from sqlalchemy.orm import joinedload
from sqlalchemy.ext.asyncio import AsyncSession

from src.core.database import TgChat, TgMessage
from src.core.workers.schemas import ResponseFromGeminiSchema
from src.core.database.successes import Success


async def bulk_create_success_reasons(
        session: AsyncSession,
        success_schema: ResponseFromGeminiSchema,
) -> None:
    stmt = (
        insert(
            Success
        )
        .values(
            [chat for chat in success_schema.model_dump_without_duplicate()["success"]]
        )
    )
    await session.execute(stmt)
    await session.commit()


async def get_messages_by_slice_id_and_user_id(
        session: AsyncSession,
        slice_id: UUID,
        user_id: int,
) -> list[TgMessage]:
    stmt = (
        select(TgMessage)
        .options(joinedload(TgMessage.user_relationship))
        .where(
            TgMessage.slice_id == slice_id,
            TgMessage.user_id == user_id,
        )
        .order_by(
            TgMessage.message_time.asc()
        )

    )
    scalars_result =  await session.scalars(stmt)

    return list(scalars_result.all())


async def success_by_slice_id   (
        session: AsyncSession,
        slice_id: UUID
) -> Success:
    stmt = (
        select(Success)
        .where(Success.slice_id == slice_id)
    )

    return await session.scalar(stmt)




